@@ -3,13 +3,13 @@ use std::collections::HashMap;
 
 #[derive(Serialize, Deserialize)]
 pub struct PathOpt {
-    jump: u16,
+    jump: usize,
     text: String,
 }
 
 impl PathOpt {
     /// Gets the place where the path is meant to jump
-    pub fn get_jump(&self) -> u16 {
+    pub fn get_jump(&self) -> usize {
         self.jump
     }
     /// Gets the text for the option
@@ -40,7 +40,7 @@ pub struct Game {
     name: String,
     author: String,
     slug: String,
-    paths: HashMap<u16, Path>,
+    paths: HashMap<usize, Path>,
 }
 
 impl Game {
@@ -57,11 +57,11 @@ impl Game {
         &self.slug
     }
     /// Getter for an arbitrary path
-    pub fn get_path(&self, id: u16) -> &Path {
+    pub fn get_path(&self, id: usize) -> &Path {
         &self.paths.get(&id).unwrap()
     }
     /// Checks to make sure that a path exists
-    pub fn check_path(&self, path: &u16) -> bool {
+    pub fn check_path(&self, path: &usize) -> bool {
         self.paths.contains_key(path)
     }
 }
